@@ -29,6 +29,7 @@ import re
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
 from typing import Any, Dict, List, Literal, Optional, Union
+from urllib.parse import urlparse
 
 from anicli_api._http import BaseHTTPAsync, BaseHTTPSync
 
@@ -48,14 +49,25 @@ class MetaVideo:
     - extra_headers - required UserAgent values for play or download this video. If not needed, default dict is empty
     """
 
-    type: Literal["mp4", "m3u8", "mpd"]
-    quality: Literal[144, 240, 360, 480, 720, 1080]
+    type: Literal["mp4", "m3u8", "mpd", "audio", "webm"]
+    quality: Literal[0, 144, 240, 360, 480, 720, 1080]
     url: str
     extra_headers: Optional[Dict] = field(default_factory=dict)
 
     def dict(self) -> Dict[str, Any]:
         return self.__dict__
 
+    def __str__(self):
+        return f"{self.type} {self.quality} {urlparse(self.url).netloc}"
+
+    def __hash__(self):
+        return hash((self.type, self.quality, urlparse(self.url).netloc))
+
+    def __eq__(self, other):
+        if isinstance(other, MetaVideo):
+            return hash(self) == hash(other)
+        raise TypeError(f"MetaVideo object required, not {type(other)}")
+
 
 class ABCDecoder(ABC):
     def __init__(self, **kwargs):
